@@ -6,6 +6,7 @@
 
 #include <assert.h>
 #include <fido.h>
+#include <string.h>
 
 #define FAKE_DEV_HANDLE	((void *)0xdeadbeef)
 #define REPORT_LEN	(64 + 1)
@@ -53,6 +54,8 @@ open_iff_ok(void)
 	fido_dev_t	*dev = NULL;
 	fido_dev_io_t	 io;
 
+	memset(&io, 0, sizeof(io));
+
 	io.open = dummy_open;
 	io.close = dummy_close;
 	io.read = dummy_read;
