@@ -101,6 +101,7 @@ print_rk(const fido_credman_rk_t *rk, size_t idx)
 	char *id = NULL;
 	char *user_id = NULL;
 	const char *type;
+	const char *prot;
 
 	if ((cred = fido_credman_rk(rk, idx)) == NULL)
 		errx(1, "fido_credman_rk");
@@ -109,23 +110,11 @@ print_rk(const fido_credman_rk_t *rk, size_t idx)
 	    fido_cred_user_id_len(cred), &user_id) < 0)
 		errx(1, "output error");
 
-	switch (fido_cred_type(cred)) {
-	case COSE_EDDSA:
-		type = "eddsa";
-		break;
-	case COSE_ES256:
-		type = "es256";
-		break;
-	case COSE_RS256:
-		type = "rs256";
-		break;
-	default:
-		type = "unknown";
-		break;
-	}
+	type = cose_string(fido_cred_type(cred));
+	prot = prot_string(fido_cred_prot(cred));
 
-	printf("%02u: %s %s (%s) %s\n", (unsigned)idx, id,
-	    fido_cred_display_name(cred), user_id, type);
+	printf("%02u: %s %s %s %s %s\n", (unsigned)idx, id,
+	    fido_cred_display_name(cred), user_id, type, prot);
 
 	free(user_id);
 	free(id);
